pkgmatch: Find R Packages Matching Either Descriptions or Other R Packages
Source:R/pkgmatch-package.R
pkgmatch-package.RdFind R packages from CRAN, rOpenSci, or Bioconductor corpora. Packages can be matched to general text descriptions, to names of installed packages, or to local paths to entire source repositories. The package is used to list the most similar packages for each new submission to the rOpenSci software peer-review program (rOpenSci authors, 2026; doi:10.5281/zenodo.18885936 ).
Author
Maintainer: Mark Padgham mark.padgham@email.com (ORCID)
Authors:
Mark Padgham mark.padgham@email.com (ORCID)
Other contributors:
Davis Vaughan davis@posit.co [contributor]