Open web pages for pkgmatch results
Arguments
- p
A
pkgmatchobject returned from pkgmatch_similar_pkgs.- n
Number of top-matching entries which should be opened. Defaults to the value passed to the main functions.
Value
(Invisibly) A named vector of integers, with 0 for all pages able to be successfully opened, and 1 otherwise.
Examples
input <- "genomics and transcriptomics sequence data"
# \donttest{
p <- pkgmatch_similar_pkgs (input, corpus = "ropensci")
# }
if (FALSE) { # \dontrun{
pkgmatch_browse (p) # Open main package pages on rOpenSci
} # }
# \donttest{
p <- pkgmatch_similar_pkgs (input, corpus = "cran")
# }
if (FALSE) { # \dontrun{
pkgmatch_browse (p) # Open main package pages on CRAN
} # }