The main pkgmatch function, pkgmatch_similar_pkgs,
returns data.frame objects of class "pkgmatch". This class exists
primarily to enable this print method, which summarises by default the top 5
matching packages or functions. Objects can be converted to standard
data.frames with as.data.frame().
Usage
# S3 method for class 'pkgmatch'
print(x, ...)Value
The result of printing x, in form of either a single character
vector, or a named list of character vectors.
Examples
if (FALSE) { # \dontrun{
input <- "Download open spatial data from NASA"
p <- pkgmatch_similar_pkgs (input)
p # Default print method, lists 5 best matching packages
head (p) # Shows first 5 rows of full `data.frame` object
} # }